@@ -97,7 +97,7 @@ struct GetGuildMembersFields {
 /// use twilight_model::id::{GuildId, UserId};
 ///
 /// # #[tokio::main]
-/// # async fn main() -> Result<(), Box<dyn std::error::Error + Send + Sync>> {
+/// # async fn main() -> Result<(), Box<dyn std::error::Error>> {
 /// let client = Client::new("my token");
 ///
 /// let guild_id = GuildId(100);
@@ -185,9 +185,8 @@ impl Future for GetGuildMembers<'_> {
                 let bytes = res?;
                 let mut members = Vec::new();
 
-                let mut bytes = bytes.as_ref().to_vec();
                 let values =
-                    crate::json::from_slice::<Vec<Value>>(&mut bytes).map_err(HttpError::json)?;
+                    crate::json::from_bytes::<Vec<Value>>(&bytes).map_err(HttpError::json)?;
 
                 for value in values {
                     let member_deserializer = MemberDeserializer::new(self.guild_id);
